@@ -1,5 +1,11 @@
+#
+# Forks::Super::Tie::BackgroundScalar - a scalar context
+#    value that is calculated in a background task
+#
+
 package Forks::Super::Tie::BackgroundScalar;
 use Forks::Super;
+use Forks::Super::Wait 'WREAP_BG_OK';
 use Carp;
 
 # a scalar reference that is evaluated in a child process.
@@ -16,15 +22,17 @@ sub TIESCALAR {
 			  sub => sub {
 			    my $Result = $command_or_code->();
 			    print STDOUT YAML::Dump($Result);
-			  } };
+			  }, _is_bg => 1 };
   } elsif ($style eq "qx") {
     $self->{command} = $command_or_code;
     $self->{stdout} = "";
     $self->{job_id} = Forks::Super::fork { %other_options, child_fh => "out",
 			  cmd => $command_or_code,
-			  stdout => \$self->{stdout} };
+			  stdout => \$self->{stdout}, _is_bg => 1 };
   }
   $self->{job} = Forks::Super::Job::get($self->{job_id});
+  $Forks::Super::LAST_JOB_ID = $self->{job_id};
+  $Forks::Super::LAST_JOB = $self->{job};
   $self->{value} = undef;
   bless $self, $class;
   return $self;
@@ -33,7 +41,7 @@ sub TIESCALAR {
 sub _retrieve_value {
   my $self = shift;
   if (!$self->{job}->is_complete) {
-    my $pid = Forks::Super::waitpid $self->{job_id}, 0;
+    my $pid = Forks::Super::waitpid $self->{job_id}, WREAP_BG_OK;
     if ($pid != $self->{job}->{real_pid}) {
       carp "Forks::Super::bg_eval: failed to retrieve result from process!\n";
       $self->{value_set} = 1;
